#!/usr/bin/env node
'use strict';

var _stellarHdWallet = require('stellar-hd-wallet');

var _stellarHdWallet2 = _interopRequireDefault(_stellarHdWallet);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PUBLIC_KEY_LENGTH = 56;

var args = process.argv.slice(2);

// Only alphanumeric seeds are valid
var words = args.filter(function (arg) {
	return (/^[a-z0-9]+$/i.test(arg)
	);
});

// We need exactly one word to search for
if (words.length != 1) {
	console.error('Usage:\n\tstellar-vanity-wallet [-p] [-m] [-s] term');
	process.exit(1);
}

var word = words[0].toUpperCase();
var suffixIndexMatch = PUBLIC_KEY_LENGTH - word.length;

// -s suffix (default)
var isMatch = function isMatch(key) {
	return key.indexOf(word) === suffixIndexMatch;
};
var where = 'as a suffix';

// -p prefix
if (args.find(function (arg) {
	return arg === '-p';
})) {
	isMatch = function isMatch(key) {
		return key.indexOf(word) === 1;
	};
	where = 'as a prefix';
	// -m middle
} else if (args.find(function (arg) {
	return arg === '-m';
})) {
	isMatch = function isMatch(key) {
		return key.indexOf(word) !== -1;
	};
	where = 'anywhere';
}

console.log('Looking for ' + word + ' ' + where);
console.log('... this may take a while ...');

var found = false;
var mnemonic = void 0;
var wallet = void 0;
var publicKey = void 0;

while (!found) {
	mnemonic = _stellarHdWallet2.default.generateMnemonic();
	wallet = _stellarHdWallet2.default.fromMnemonic(mnemonic);
	publicKey = wallet.getPublicKey(0);
	// console.log('checking', publicKey);
	if (isMatch(publicKey)) {
		found = true;
	}
}

var secretKey = wallet.getSecret(0);

console.log('Public Key: ' + publicKey);
console.log('Secret Key: ' + secretKey);
console.log('Mnemonic:   ' + mnemonic);